@@ -1,8 +1,8 @@
 
-__version__ = "0.11.1"
+__version__ = "0.11.2"
 __version_vcs_info__ = {
-    'branch': 'master',
-    'revid': '9b2dba5',
-    'revno': 1916}
+    'branch': 'hotfix-0.11.2',
+    'revid': 'b67dde5',
+    'revno': 1918}
 __version_user_email__ = "saxtouri@admin.grnet.gr"
 __version_user_name__ = "Stavros Sachtouris"
